==> pcl_1.9.1+dfsg1.orig.tar.xz: pcl-pcl-1.9.1/visualization/include/pcl/visualization/common/io.h <==
/*
 * Software License Agreement (BSD License)
 *
 *  Point Cloud Library (PCL) - www.pointclouds.org
 *  Copyright (c) 2010, Willow Garage, Inc.
 *  Copyright (c) 2012-, Open Perception, Inc.
 *
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of the copyright holder(s) nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */
#ifndef PCL_PCL_VISUALIZER_COMMON_IO_H_
#define PCL_PCL_VISUALIZER_COMMON_IO_H_

#include <pcl/visualization/common/actor_map.h>
#include <pcl/kdtree/kdtree_flann.h>
#include <pcl/console/print.h>

class vtkPolyData;

namespace pcl
{
  namespace visualization
  {
    /** \brief Obtain a list of corresponding indices, for a set of vtk points, 
      * from a pcl::PointCloud
      * \param src the set of vtk points
      * \param tgt the target pcl::PointCloud that we need to obtain indices from
      * \param indices the resultant list of indices
      * \ingroup visualization
      */
    PCL_EXPORTS void 
    getCorrespondingPointCloud (vtkPolyData *src, const pcl::PointCloud<pcl::PointXYZ> &tgt, std::vector<int> &indices);

    /** \brief Saves the vtk-formatted Point Cloud data into a set of files, based on whether
      * the data comes from previously loaded PCD files. The PCD files are matched using the 
      * a list of names for the actors on screen.
      * \param data the vtk data
      * \param out_file the output file (extra indices will be appended to it)
      * \param actors the list of actors present on screen
      * \ingroup visualization
      */
    PCL_EXPORTS bool 
    savePointData (vtkPolyData* data, const std::string &out_file, const boost::shared_ptr<CloudActorMap> &actors);
  }
}

#endif

==> pcl_1.10.0+dfsg.orig.tar.xz: pcl-pcl-1.10.0/visualization/include/pcl/visualization/common/io.h <==
/*
 * Software License Agreement (BSD License)
 *
 *  Point Cloud Library (PCL) - www.pointclouds.org
 *  Copyright (c) 2010, Willow Garage, Inc.
 *  Copyright (c) 2012-, Open Perception, Inc.
 *
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of the copyright holder(s) nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 */

#pragma once

#include <pcl/visualization/common/actor_map.h>
#include <pcl/console/print.h>

class vtkPolyData;

namespace pcl
{
  namespace visualization
  {
    /** \brief Obtain a list of corresponding indices, for a set of vtk points, 
      * from a pcl::PointCloud
      * \param src the set of vtk points
      * \param tgt the target pcl::PointCloud that we need to obtain indices from
      * \param indices the resultant list of indices
      * \ingroup visualization
      */
    PCL_EXPORTS void 
    getCorrespondingPointCloud (vtkPolyData *src, const pcl::PointCloud<pcl::PointXYZ> &tgt, std::vector<int> &indices);

    /** \brief Saves the vtk-formatted Point Cloud data into a set of files, based on whether
      * the data comes from previously loaded PCD files. The PCD files are matched using the 
      * a list of names for the actors on screen.
      * \param data the vtk data
      * \param out_file the output file (extra indices will be appended to it)
      * \param actors the list of actors present on screen
      * \ingroup visualization
      */
    PCL_EXPORTS bool 
    savePointData (vtkPolyData* data, const std::string &out_file, const CloudActorMapPtr &actors);
  }
}
